import React, { useState, Suspense, lazy, useEffect, useRef, useLayoutEffect } from 'react';
import { v4 as uuidv4 } from 'uuid';
import { Toaster, toast } from 'react-hot-toast';
import { HelmetProvider, Helmet } from 'react-helmet-async';
import { ErrorBoundary } from 'react-error-boundary';
import { downloadProcessedImage, getFileInfo, estimateOutputSize, convertPdfToImage } from './utils/imageProcessing';
import { OutputFormat, SelectedSize, ProcessedImage, PrintSize, FileInfo } from './types';
import { ImagePreview } from './components/ImagePreview';

// Yeni PDF dönüştürme modülünü import et
import { convertPdfWithFallback } from './utils/pdfConverter';

// Simplify the lazy imports
const ImageUploader = lazy(() => import('./components/ImageUploader'));
const SizeSelector = lazy(() => 
  import('./components/SizeSelector').then(module => ({ default: module.SizeSelector }))
);
const ConversionSettings = lazy(() => import('./components/ConversionSettings'));

// Modern UI için yeni Hero bileşeni
const HeroSection = React.memo(() => {
  return (
    <header className="bg-gradient-to-r from-blue-700 to-indigo-800 py-8 md:py-16 relative overflow-hidden">
      {/* Dekoratif arka plan elementleri */}
      <div className="absolute inset-0 bg-black/30 mix-blend-multiply"></div>
      <div className="absolute inset-0 opacity-10">
        <div className="absolute inset-0 bg-repeat" style={{ 
          backgroundImage: 'url("/pattern.svg")', 
          backgroundSize: '200px',
        }}></div>
      </div>
      
      {/* Dekoratif şekiller */}
      <div className="absolute right-0 top-0 -translate-y-1/4 translate-x-1/4 w-64 h-64 bg-gradient-to-br from-blue-400/20 to-indigo-500/20 rounded-full blur-3xl"></div>
      <div className="absolute left-0 bottom-0 translate-y-1/3 -translate-x-1/3 w-96 h-96 bg-gradient-to-tr from-purple-500/10 to-pink-500/10 rounded-full blur-3xl"></div>
      
      <div className="max-w-7xl mx-auto px-4 sm:px-6 relative z-10">
        <div className="max-w-3xl mx-auto text-center space-y-5 md:space-y-7">
          {/* Ana başlık - image dpi converter vurgusu */}
          <div className="inline-block">
            <span className="inline-flex items-center px-3 py-1 text-xs font-medium rounded-full bg-blue-500/20 text-blue-200 backdrop-blur-sm mb-3">
              <span className="animate-pulse mr-1.5 h-2 w-2 rounded-full bg-blue-200"></span>
              Free online tool
            </span>
          </div>
          
          <h1 
            className="text-3xl md:text-4xl lg:text-5xl xl:text-6xl font-extrabold tracking-tight text-white"
            id="main-heading"
          >
            Image <span className="text-blue-300">DPI Converter</span>
          </h1>
          
          {/* Alt metin - SEO optimizasyonu korundu */}
          <p 
            id="react-hero-text"
            className="text-base md:text-xl text-blue-100/90 leading-relaxed max-w-2xl mx-auto"
          >
            Easily modify the DPI of any image format. Convert to 72-600 DPI for perfect print quality with our user-friendly tool. Supports JPEG, PNG, GIF and more.
          </p>
          
          {/* Modern tasarımlı özellik kartları */}
          <div className="grid grid-cols-1 sm:grid-cols-3 gap-3 md:gap-5 mt-8">
            {[
              { 
                title: 'Convert Common Image Formats', 
                desc: 'JPG, PNG, GIF and more formats supported',
                icon: '📁'
              },
              { 
                title: 'Set Desired DPI', 
                desc: 'From 72 DPI to 600 DPI (dots per inch)',
                icon: '🎯'
              },
              { 
                title: 'Convert Images in Bulk', 
                desc: 'Process multiple files at once',
                icon: '⚡'
              }
            ].map(feature => (
              <div key={feature.title} className="bg-white/10 backdrop-blur-md rounded-xl p-5 text-white border border-white/10 hover:border-blue-400/30 transition-all hover:shadow-lg hover:shadow-blue-500/10">
                <span className="text-2xl mb-3 block">{feature.icon}</span>
                <h2 className="font-medium text-lg text-blue-100">{feature.title}</h2>
                <p className="text-sm text-blue-200/80 mt-2">{feature.desc}</p>
              </div>
            ))}
          </div>
        </div>
      </div>
    </header>
  );
});

// Declare the LCPReporter for TypeScript
interface Window {
  LCPReporter?: (element: HTMLElement) => void;
  dataLayer: any[];
}

// Google Analytics izleme fonksiyonları
const initializeAnalytics = () => {
  // Eğer zaten yüklenmişse tekrar ekleme
  if (window.dataLayer) return;
  
  window.dataLayer = window.dataLayer || [];
  function gtag(...args: any[]) {
    window.dataLayer.push(arguments);
  }
  gtag('js', new Date());
  gtag('config', 'G-PE4BX79TLP', { send_page_view: false });
};

const trackEvent = (category: string, action: string, label?: string, value?: number) => {
  if (!window.dataLayer) return;
  
  window.dataLayer.push({
    event: 'custom_event',
    event_category: category,
    event_action: action,
    event_label: label,
    event_value: value
  });
};

// Ana Uygulama Bileşeni
function App() {
  const [selectedSizes, setSelectedSizes] = useState<SelectedSize[]>([]);
  const [processedImages, setProcessedImages] = useState<ProcessedImage[]>([]);
  const [isProcessing, setIsProcessing] = useState(false);
  const [selectedFormat, setSelectedFormat] = useState<OutputFormat>('png');
  const [editingImageId, setEditingImageId] = useState<string | null>(null);
  const [baseFileName, setBaseFileName] = useState<string>('');
  const [isEditingName, setIsEditingName] = useState(false);
  const [customDpi, setCustomDpi] = useState(300);
  
  // SEO için zenginleştirilmiş açıklamalar ve meta etiketleri - image dpi converter vurgusu
  const pageMeta = {
    title: "Image DPI Converter | Convert Images to 72-600 DPI Online",
    description: "Free image DPI converter to modify the DPI of any image. Our online tool converts JPG, PNG, GIF formats with high quality to your desired DPI (72-600 dots per inch).",
    keywords: "image dpi converter, image dpi conversions, online dpi converter, convert dpi, dpi changer, dpi conversion, photo dpi converter, dots per inch, jpg png, convert any image format, high quality, jpeg png gif, 600 dpi, modify the dpi of an image"
  };

  // Update size estimations when settings change
  useEffect(() => {
    updateSizeEstimates();
  }, [selectedSizes, selectedFormat, customDpi]);

  // Analytics izleme için yeni effect
  useEffect(() => {
    // Google Analytics'i başlat
    initializeAnalytics();
    
    // Sayfa görüntülemeyi kaydet
    if (window.dataLayer) {
      window.dataLayer.push({
        event: 'page_view',
        page_title: pageMeta.title,
        page_location: window.location.href,
        page_path: window.location.pathname
      });
    }
  }, []);

  const updateSizeEstimates = () => {
    if (processedImages.length === 0) return;
    
    const activeSizes = selectedSizes.filter(s => s.isSelected);
    if (activeSizes.length === 0) return;
    
    setProcessedImages(prevImages => 
      prevImages.map(img => {
        if (!img.dimensions.width) return img;
        
        const estimatedSizes: Record<string, number> = {};
        activeSizes.forEach(size => {
          const estimate = estimateOutputSize(
            img.size,
            img.dimensions,
            size,
            selectedFormat,
            img.dpi || 72,
            customDpi
          );
          const sizeKey = `${size.name}_${selectedFormat}`;
          estimatedSizes[sizeKey] = estimate;
        });
        
        return {
          ...img,
          estimatedSizes
        };
      })
    );
  };

  const handleSizeToggle = (size: PrintSize) => {
    setSelectedSizes(prev => {
      const exists = prev.find(s => s.name === size.name);
      if (exists) {
        return prev.map(s => 
          s.name === size.name 
            ? { ...s, isSelected: !s.isSelected }
            : s
        );
      }
      return [...prev, { ...size, isSelected: true }];
    });
  };

  const handleFormatChange = (format: string) => {
    // OutputFormat tipine dönüştürme yapıyoruz
    setSelectedFormat(format as OutputFormat);
  };

  const handleImageUpload = async (file: File) => {
    const baseName = file.name.replace(/\.[^/.]+$/, "");
    
    toast.loading('Analyzing file...', { id: 'file-analysis' });
    
    try {
      const fileInfo = await getFileInfo(file);
      
      let fileToProcess = file;
      
      // PDF dönüştürme işlemi için yeni modülü kullanıyoruz
      if (file.type === 'application/pdf') {
        const shouldConvert = window.confirm('Do you want to convert this PDF to an image?');
        if (shouldConvert) {
          toast.loading('Converting PDF to image...', { id: 'pdf-conversion' });
          
          try {
            // Yeni PDF dönüştürme modülünü kullan
            fileToProcess = await convertPdfWithFallback(
              file, 
              selectedFormat as 'jpeg' | 'png' || 'png', 
              customDpi
            );
            toast.success('PDF converted to image!', { id: 'pdf-conversion' });
          } catch (pdfError) {
            console.error('PDF conversion error:', pdfError);
            toast.error('Failed to convert PDF. Please try again or use a different file.', { id: 'pdf-conversion' });
            // Hata durumunda işlemi iptal et
            toast.dismiss('file-analysis');
            return;
          }
        }
      }
      
      const newImage: ProcessedImage = {
        id: uuidv4(),
        file: fileToProcess,
        name: baseName,
        originalName: baseName,
        preview: URL.createObjectURL(fileToProcess),
        size: fileToProcess.size,
        dimensions: fileInfo.dimensions,
        dpi: fileInfo.dpi,
        fileType: fileInfo.fileType
      };

      setProcessedImages(prev => [...prev, newImage]);
      toast.success('File uploaded successfully!');
      
      // Dosya yüklemeyi izle
      trackEvent('File', 'Upload', file.type, Math.round(file.size / 1024));
      
      // toast.info yerine toast.success veya toast kullan
      if (selectedSizes.filter(s => s.isSelected).length === 0) {
        toast('Please select print sizes', {
          icon: '📏',
          duration: 4000
        });
      }
    } catch (error) {
      console.error('File upload error:', error);
      toast.error('Failed to process file');
    } finally {
      toast.dismiss('file-analysis');
    }
  };

  const getFormattedFileName = (baseName: string, size: PrintSize) => {
    const fileName = baseFileName || baseName;
    return `${fileName}_${size.width}x${size.height}_${customDpi}dpi`;
  };

  const handleBulkDownload = async () => {
    if (processedImages.length === 0) {
      toast.error('No images to process');
      return;
    }

    const activeSizes = selectedSizes.filter(s => s.isSelected);
    if (activeSizes.length === 0) {
      toast.error('Please select at least one size');
      return;
    }

    setIsProcessing(true);
    const total = processedImages.length * activeSizes.length;
    let processed = 0;

    try {
      const toastId = toast.loading(`Processing 0/${total} images...`);
      
      for (const image of processedImages) {
        for (const size of activeSizes) {
          try {
            const fileName = getFormattedFileName(image.name, size);
            await downloadProcessedImage(
              image.file,
              size,
              selectedFormat,
              `${fileName}.${selectedFormat}`
            );
            processed++;
            toast.loading(`Processing ${processed}/${total} images...`, { id: toastId });
          } catch (error) {
            console.error('Failed to process image:', error);
          }
        }
      }
      
      toast.success(`Successfully processed ${processed}/${total} images!`, { id: toastId });
      
      // İndirme işlemini izle
      trackEvent('Conversion', 'Bulk Download', selectedFormat, processedImages.length);
    } catch (error) {
      console.error('Bulk download error:', error);
      toast.error('Failed to process some images');
    } finally {
      setIsProcessing(false);
    }
  };

  async function handleDownloadSingle(size: SelectedSize) {
    const imageToProcess = processedImages[0];
    if (!imageToProcess) return;
  
    setIsProcessing(true);
    try {
      const printSize: PrintSize = {
        name: size.name,
        width: size.width,
        height: size.height,
        category: size.category
      };
  
      const fileName = getFormattedFileName(imageToProcess.name, printSize);
      
      await downloadProcessedImage(
        imageToProcess.file,
        printSize,
        selectedFormat,
        fileName
      );
      toast.success('File downloaded successfully');
    } catch (error) {
      console.error('Download error:', error);
      toast.error('Failed to download file');
    } finally {
      setIsProcessing(false);
    }
  }

  const handleRemoveImage = (id: string) => {
    setProcessedImages(prev => prev.filter(img => img.id !== id));
  };

  const handleNameChange = (id: string, newName: string) => {
    setProcessedImages(prev => prev.map(img => 
      img.id === id ? { ...img, name: newName } : img
    ));
    setEditingImageId(null);
  };

  const formatFileSize = (bytes: number) => {
    if (bytes < 1024) return bytes + ' B';
    else if (bytes < 1048576) return (bytes / 1024).toFixed(2) + ' KB';
    else return (bytes / 1048576).toFixed(2) + ' MB';
  };

  const renderImageList = () => (
    <div className="space-y-3">
      {processedImages.map(image => (
        <ImagePreview
          key={image.id}
          image={image}
          selectedSizes={selectedSizes}
          onDownload={handleDownloadSingle}
          onRemove={handleRemoveImage}
          onNameChange={handleNameChange}
          isProcessing={isProcessing}
        />
      ))}
    </div>
  );

  // File name preview helper function
  const getFileNamePreview = (size: PrintSize) => {
    return `${baseFileName || 'untitled'}_${size.width}x${size.height}_${customDpi}dpi.${selectedFormat}`;
  };

  // Hero elementini daha erken render etmek için ref kullan
  const heroRef = useRef<HTMLDivElement>(null);

  // Sayfa yüklenme zamanını takip etmek ve LCP optimizasyonu için
  useLayoutEffect(() => {
    // Report the hero text as the LCP element as early as possible
    window.LCPReporter = (element) => {
      if (element && 'PerformanceObserver' in window) {
        try {
          // Create a mark for performance measurement
          performance.mark('hero-text-displayed');
        } catch (e) {
          // Silent error for environments without perf API
        }
      }
    };

    // Clean up
    return () => {
      delete window.LCPReporter;
    };
  }, []);

  // Modern UI için yenilenmiş SEO içeriği
  const renderSEOContent = () => (
    <section className="bg-white rounded-xl shadow-sm border p-6">
      <h2 className="text-xl font-semibold text-gray-900 mb-4">About Our Image DPI Converter</h2>
      <div className="prose prose-sm max-w-none text-gray-600">
        <p className="leading-relaxed">
          Our <strong>free image DPI converter</strong> lets you modify the DPI of any image quickly and easily. 
          Convert common image formats like <strong>JPG, PNG, and GIF</strong> to any desired DPI setting, 
          from <strong>72 DPI</strong> (standard screen resolution) to <strong>600 DPI</strong> (high quality print).
        </p>
        <p className="mt-3 leading-relaxed">
          Whether you need to adjust dots per inch for professional printing or digital display, our 
          user-friendly image DPI converter makes conversion simple and efficient. This DPI changer converts images 
          without losing quality, ensuring your converted images maintain their original clarity.
        </p>
        <p className="mt-3 leading-relaxed">
          Need to convert images in bulk? Our image DPI converter handles that too, saving you time by processing multiple 
          files at once. Experience high quality image DPI conversions with our powerful yet simple converter.
        </p>
      </div>
      
      <div className="mt-6 grid grid-cols-1 md:grid-cols-2 gap-4">
        <div className="bg-blue-50 p-4 rounded-xl border border-blue-100">
          <h3 className="text-sm font-medium text-blue-800 flex items-center">
            <svg xmlns="http://www.w3.org/2000/svg" className="h-4 w-4 mr-2" viewBox="0 0 20 20" fill="currentColor">
              <path fillRule="evenodd" d="M10 18a8 8 0 100-16 8 8 0 000 16zm3.707-9.293a1 1 0 00-1.414-1.414L9 10.586 7.707 9.293a1 1 0 00-1.414 1.414l2 2a1 1 0 001.414 0l4-4z" clipRule="evenodd" />
            </svg>
            Supported Input Formats
          </h3>
          <p className="text-xs text-blue-700 mt-2">JPEG, PNG, GIF, BMP, WEBP and more file types</p>
        </div>
        <div className="bg-green-50 p-4 rounded-xl border border-green-100">
          <h3 className="text-sm font-medium text-green-800 flex items-center">
            <svg xmlns="http://www.w3.org/2000/svg" className="h-4 w-4 mr-2" viewBox="0 0 20 20" fill="currentColor">
              <path fillRule="evenodd" d="M10 18a8 8 0 100-16 8 8 0 000 16zm3.707-9.293a1 1 0 00-1.414-1.414L9 10.586 7.707 9.293a1 1 0 00-1.414 1.414l2 2a1 1 0 001.414 0l4-4z" clipRule="evenodd" />
            </svg>
            DPI Range Options
          </h3>
          <p className="text-xs text-green-700 mt-2">72, 96, 150, 300, 600 DPI and custom settings</p>
        </div>
      </div>
    </section>
  );

  return (
    <ErrorBoundary 
      fallbackRender={({ error }) => (
        <div className="p-8 text-center">
          <h3 className="text-lg font-medium text-red-600">Something went wrong</h3>
          <p className="mt-2 text-gray-600">{error.message}</p>
        </div>
      )}
    >
      <HelmetProvider>
        <div className="min-h-screen bg-gradient-to-br from-slate-50 to-slate-100">
          <Helmet>
            <title>{pageMeta.title}</title>
            <meta name="description" content={pageMeta.description} />
            <meta name="keywords" content={pageMeta.keywords} />
            {/* Image DPI Converter için ek meta etiketleri */}
            <meta property="og:title" content="Image DPI Converter | Free Online Tool" />
            <meta property="og:description" content="Convert any image DPI settings with our free online image DPI converter. Perfect for print preparation." />
            {/* ...existing meta tags... */}
          </Helmet>
          
          {/* Modern Hero bölümü */}
          <HeroSection />

          <main className="max-w-5xl mx-auto px-4 py-6 md:py-8 -mt-10 md:-mt-20 relative z-10">
            {/* Modern adım göstergesi */}
            <div className="bg-white backdrop-blur-sm rounded-xl shadow-sm border border-gray-200 mb-6 p-4 hidden sm:block">
              <div className="flex items-center justify-center space-x-3 text-sm">
                {[
                  { step: 1, text: 'Upload Files' },
                  { step: 2, text: 'Select Sizes' },
                  { step: 3, text: 'Configure Settings' },
                  { step: 4, text: 'Download' }
                ].map((item, i) => (
                  <React.Fragment key={item.step}>
                    <div className={`flex items-center space-x-2 ${
                      (processedImages.length > 0 && item.step <= 2) ||
                      (selectedSizes.some(s => s.isSelected) && item.step <= 3) ||
                      (isProcessing && item.step === 4)
                        ? 'text-blue-600'
                        : 'text-gray-400'
                    }`}>
                      <span className="w-8 h-8 rounded-full flex items-center justify-center font-medium text-sm
                        ${(processedImages.length > 0 && item.step <= 2) ||
                          (selectedSizes.some(s => s.isSelected) && item.step <= 3) ||
                          (isProcessing && item.step === 4)
                            ? 'bg-blue-100 text-blue-600 border-2 border-blue-200'
                            : 'bg-gray-100 text-gray-500 border border-gray-200'
                        }">
                        {item.step}
                      </span>
                      <span>{item.text}</span>
                    </div>
                    {i < 3 && (
                      <div className="w-12 h-px bg-gray-200 relative">
                        {((processedImages.length > 0 && i < 1) ||
                          (selectedSizes.some(s => s.isSelected) && i < 2) ||
                          (isProcessing && i < 3)) && (
                          <div className="absolute inset-0 bg-blue-500 transition-all duration-500"></div>
                        )}
                      </div>
                    )}
                  </React.Fragment>
                ))}
              </div>
            </div>

            {/* Ana içerik grid - modern tasarım */}
            <div className="grid grid-cols-1 lg:grid-cols-5 gap-6">
              {/* Sol Kolon - modernize edildi */}
              <div className="lg:col-span-3 space-y-6">
                {/* Upload Alanı */}
                <div className="bg-white rounded-xl shadow-sm border border-gray-200 p-5 transition-all hover:shadow-md">
                  <h2 className="text-lg font-medium text-gray-800 mb-4">Upload Files</h2>
                  <Suspense fallback={<div className="animate-pulse h-32 bg-gray-100 rounded-lg"></div>}>
                    <ImageUploader onImageUpload={handleImageUpload} acceptPdf={true} />
                  </Suspense>
                </div>

                {/* Yüklenen Dosyalar */}
                {processedImages.length > 0 && (
                  <div className="bg-white rounded-xl shadow-sm border border-gray-200 p-5 transition-all hover:shadow-md">
                    <h2 className="text-lg font-medium text-gray-800 mb-4">Uploaded Files</h2>
                    {renderImageList()}
                  </div>
                )}
              </div>

              {/* Sağ Kolon - modernize edildi */}
              <div className="lg:col-span-2 space-y-6">
                {/* Print Sizes */}
                <div className="bg-white rounded-xl shadow-sm border border-gray-200 p-5 transition-all hover:shadow-md">
                  <h2 className="text-lg font-medium text-gray-800 mb-4">Print Sizes</h2>
                  <Suspense fallback={<div className="animate-pulse h-32 bg-gray-100 rounded-lg"></div>}>
                    <SizeSelector 
                      selectedSizes={selectedSizes}
                      onSizeToggle={handleSizeToggle}
                      selectedFormat={selectedFormat}
                      onFormatChange={handleFormatChange}
                    />
                  </Suspense>
                </div>

                {/* DPI ve Format Ayarları */}
                <Suspense fallback={<div className="animate-pulse h-32 bg-gray-100 rounded-lg"></div>}>
                  <div className="bg-white rounded-xl shadow-sm border border-gray-200 p-5 transition-all hover:shadow-md">
                    <ConversionSettings
                      dpi={customDpi}
                      onDpiChange={setCustomDpi}
                      format={selectedFormat}
                      onFormatChange={handleFormatChange}
                    >
                      {/* DPI açıklama */}
                      <div className="mt-3 text-xs text-gray-500 bg-blue-50 border border-blue-100 rounded-lg p-3">
                        <p className="flex items-center">
                          <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                            <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M13 16h-1v-4h-1m1-4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z" />
                          </svg>
                          DPI (dots per inch) affects print quality. Higher DPI values like 300 or 600 DPI create sharper printed images.
                        </p>
                      </div>
                      
                      {/* Download butonu */}
                      {processedImages.length > 0 && selectedSizes.some(s => s.isSelected) && (
                        <div className="mt-5 pt-4 border-t">
                          <div className="flex items-center justify-between mb-3">
                            <span className="text-sm text-gray-600 font-medium">
                              {processedImages.length} file(s) × {selectedSizes.filter(s => s.isSelected).length} size(s)
                            </span>
                          </div>
                          <button
                            onClick={handleBulkDownload}
                            disabled={isProcessing}
                            className={`
                              w-full py-3 px-4 rounded-lg font-medium text-sm text-center
                              transition-all
                              ${isProcessing
                                ? 'bg-gray-100 text-gray-400 cursor-not-allowed'
                                : 'bg-gradient-to-r from-blue-600 to-blue-700 hover:from-blue-700 hover:to-blue-800 text-white shadow-sm hover:shadow'}
                            `}
                            aria-label="Process and download all files"
                          >
                            {isProcessing ? (
                              <span className="flex items-center justify-center gap-2">
                                <svg className="animate-spin h-4 w-4" viewBox="0 0 24 24" role="presentation" aria-hidden="true">
                                  <circle className="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" strokeWidth="4" fill="none"/>
                                  <path className="opacity-75" fill="currentColor" d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"/>
                                </svg>
                                Processing...
                              </span>
                            ) : (
                              <span className="flex items-center justify-center gap-2">
                                <svg className="h-4 w-4" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M4 16v1a3 3 0 003 3h10a3 3 0 003-3v-1m-4-4l-4 4m0 0l-4-4m4 4V4" />
                                </svg>
                                Process & Download All
                              </span>
                            )}
                          </button>
                        </div>
                      )}
                    </ConversionSettings>
                  </div>
                </Suspense>
                
                {/* DPI Conversion FAQs */}
                <div className="bg-white rounded-xl shadow-sm border border-gray-200 p-5 transition-all hover:shadow-md">
                  <h2 className="text-lg font-medium text-gray-800 mb-4">DPI Conversion FAQ</h2>
                  <div className="space-y-3">
                    <details className="group">
                      <summary className="flex items-center justify-between cursor-pointer text-sm font-medium text-gray-700 p-3 rounded-lg bg-gray-50 hover:bg-gray-100 transition-colors">
                        <span>What is DPI in images?</span>
                        <svg className="h-4 w-4 text-gray-500 group-open:rotate-180 transition-transform" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M19 9l-7 7-7-7" />
                        </svg>
                      </summary>
                      <p className="mt-2 text-sm text-gray-600 px-3">
                        DPI (dots per inch) measures print resolution. It determines how many dots of ink are printed per inch, affecting image quality.
                      </p>
                    </details>
                    
                    <details className="group">
                      <summary className="flex items-center justify-between cursor-pointer text-sm font-medium text-gray-700 p-3 rounded-lg bg-gray-50 hover:bg-gray-100 transition-colors">
                        <span>Why convert image DPI?</span>
                        <svg className="h-4 w-4 text-gray-500 group-open:rotate-180 transition-transform" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M19 9l-7 7-7-7" />
                        </svg>
                      </summary>
                      <p className="mt-2 text-sm text-gray-600 px-3">
                        Higher DPI (like 300-600) is ideal for printing, while lower DPI (72-96) is suitable for digital display and web use.
                      </p>
                    </details>
                    
                    <details className="group">
                      <summary className="flex items-center justify-between cursor-pointer text-sm font-medium text-gray-700 p-3 rounded-lg bg-gray-50 hover:bg-gray-100 transition-colors">
                        <span>Will changing DPI affect image quality?</span>
                        <svg className="h-4 w-4 text-gray-500 group-open:rotate-180 transition-transform" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                          <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M19 9l-7 7-7-7" />
                        </svg>
                      </summary>
                      <p className="mt-2 text-sm text-gray-600 px-3">
                        Our DPI converter preserves image quality while adjusting resolution. For best results when increasing DPI, start with high-resolution images.
                      </p>
                    </details>
                  </div>
                </div>
              </div>
            </div>
            
            {/* Platform bilgi kartları - modernize edilmiş */}
            <div className="mt-8 pt-6 border-t border-gray-200">
              <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
                <div className="bg-white rounded-xl shadow-sm border border-gray-200 p-5 transition-all hover:shadow-md hover:border-blue-200">
                  <div className="rounded-full bg-blue-50 h-12 w-12 flex items-center justify-center text-blue-600 mb-4">
                    <svg className="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12l2 2 4-4m5.618-4.016A11.955 11.955 0 0112 2.944a11.955 11.955 0 01-8.618 3.04A12.02 12.02 0 003 9c0 5.591 3.824 10.29 9 11.622 5.176-1.332 9-6.03 9-11.622 0-1.042-.133-2.052-.382-3.016z" />
                    </svg>
                  </div>
                  <h3 className="font-medium text-gray-800 mb-2">Why Use Our Image DPI Converter</h3>
                  <p className="text-sm text-gray-600">Our tool makes it easy to convert images to the right DPI for any purpose, whether it's printing, publishing, or digital display.</p>
                </div>
                
                <div className="bg-white rounded-xl shadow-sm border border-gray-200 p-5 transition-all hover:shadow-md hover:border-blue-200">
                  <div className="rounded-full bg-blue-50 h-12 w-12 flex items-center justify-center text-blue-600 mb-4">
                    <svg className="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9.75 17L9 20l-1 1h8l-1-1-.75-3M3 13h18M5 17h14a2 2 0 002-2V5a2 2 0 00-2-2H5a2 2 0 00-2 2v10a2 2 0 002 2z" />
                    </svg>
                  </div>
                  <h3 className="font-medium text-gray-800 mb-2">Supported Platforms</h3>
                  <p className="text-sm text-gray-600">Works on Windows, macOS, Linux, iOS and Android - no software installation required.</p>
                </div>
                
                <div className="bg-white rounded-xl shadow-sm border border-gray-200 p-5 transition-all hover:shadow-md hover:border-blue-200">
                  <div className="rounded-full bg-blue-50 h-12 w-12 flex items-center justify-center text-blue-600 mb-4">
                    <svg className="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                      <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 15v2m-6 4h12a2 2 0 002-2v-6a2 2 0 00-2-2H6a2 2 0 00-2 2v6a2 2 0 002 2zm10-10V7a4 4 0 00-8 0v4h8z" />
                    </svg>
                  </div>
                  <h3 className="font-medium text-gray-800 mb-2">Security & Privacy</h3>
                  <p className="text-sm text-gray-600">All image processing happens in your browser. Your files are never uploaded to our servers.</p>
                </div>
              </div>
            </div>
            
            {/* SEO içeriği sayfanın alt kısmında - modernize edildi */}
            <div className="mt-12 pt-6 border-t border-gray-200">
              {renderSEOContent()}
            </div>
          </main>

          {/* Modernize edilmiş footer */}
          <footer className="bg-gradient-to-b from-slate-50 to-white border-t border-gray-200 mt-16 py-12 md:py-16" style={{position: 'relative', zIndex: 20}}>
            <div className="max-w-7xl mx-auto px-4 md:px-6">
              <div className="grid grid-cols-1 md:grid-cols-3 gap-12">
                <div>
                  <h2 className="text-xl font-bold text-gray-800 mb-4">Image DPI Converter Online</h2>
                  <p className="text-gray-600 mb-6">
                    Our free image DPI converter helps you convert JPG, PNG, GIF and other image formats to your desired DPI with a user-friendly interface.
                  </p>
                  <div className="flex space-x-4">
                    <a href="#" className="text-gray-400 hover:text-blue-600">
                      <span className="sr-only">Twitter</span>
                      <svg className="h-6 w-6" fill="currentColor" viewBox="0 0 24 24">
                        <path d="M8.29 20.251c7.547 0 11.675-6.253 11.675-11.675 0-.178 0-.355-.012-.53A8.348 8.348 0 0022 5.92a8.19 8.19 0 01-2.357.646 4.118 4.118 0 001.804-2.27 8.224 8.224 0 01-2.605.996 4.107 4.107 0 00-6.993 3.743 11.65 11.65 0 01-8.457-4.287 4.106 4.106 0 001.27 5.477A4.072 4.072 0 012.8 9.713v.052a4.105 4.105 0 003.292 4.022 4.095 4.095 0 01-1.853.07 4.108 4.108 0 003.834 2.85A8.233 8.233 0 012 18.407a11.616 11.616 0 006.29 1.84"></path>
                      </svg>
                    </a>
                  </div>
                </div>
                
                <div>
                  <h3 className="text-lg font-bold text-gray-800 mb-4">Features</h3>
                  <ul className="space-y-3 text-gray-600">
                    <li className="flex items-center">
                      <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                      </svg>
                      Convert any image format
                    </li>
                    <li className="flex items-center">
                      <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                      </svg>
                      High quality DPI conversion
                    </li>
                    <li className="flex items-center">
                      <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                      </svg>
                      Modify DPI from 72 to 600
                    </li>
                    <li className="flex items-center">
                      <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                      </svg>
                      Bulk image processing
                    </li>
                    <li className="flex items-center">
                      <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                      </svg>
                      User-friendly interface
                    </li>
                  </ul>
                </div>
                
                <div>
                  <h3 className="text-lg font-bold text-gray-800 mb-4">Common Uses</h3>
                  <ul className="space-y-3 text-gray-600">
                    <li className="flex items-center">
                      <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                      </svg>
                      Preparing images for print
                    </li>
                    <li className="flex items-center">
                      <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                      </svg>
                      Converting web images to print quality
                    </li>
                    <li className="flex items-center">
                      <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                      </svg>
                      Reducing file size for web
                    </li>
                    <li className="flex items-center">
                      <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                      </svg>
                      Meeting publishing requirements
                    </li>
                    <li className="flex items-center">
                      <svg className="h-4 w-4 mr-2 text-blue-500" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M5 13l4 4L19 7" />
                      </svg>
                      Professional photography work
                    </li>
                  </ul>
                </div>
              </div>
              <div className="border-t border-gray-200 mt-8 pt-6 text-center text-sm text-gray-500">
                © {new Date().getFullYear()} Free Image DPI Converter - Convert images with precision
              </div>
            </div>
          </footer>

          <Toaster 
            position="bottom-right"
            toastOptions={{
              className: 'rounded-xl shadow-lg border border-gray-100',
              duration: 3000,
            }} 
          />
        </div>
      </HelmetProvider>
    </ErrorBoundary>
  );
}

export default App;